@@ -62,7 +62,7 @@ class PostgresDataSource(ToucanDataSource):
                     )
                     res = cursor.fetchall()
                     available_tables = [table_name for (_, table_name) in res]
-                    constraints['table'] = strlist_to_enum('table', available_tables)
+                    constraints['table'] = strlist_to_enum('table', available_tables, None)
 
         return create_model('FormSchema', **constraints, __base__=cls).schema()
 
